@@ -1,5 +1,5 @@
 import easydev
-from easydev.platform import get_platform, linux_distribution, is_windows
+from easydev.platform import get_platform, is_windows
 from easydev.platform import is_linux, is_mac
 
 
@@ -7,7 +7,6 @@ def test_platform(mocker):
 
     assert get_platform() in ['Linux', 'Windows', 'Mac']
 
-    linux_distribution()
 
     is_windows()
     is_linux()
